@@ -1,3 +1,4 @@
+import re
 import urlparse
 from django.db import models
 
@@ -10,8 +11,14 @@ class YouTubeEmbedField(models.URLField):
 
         if value and not value.startswith(youtube_embed_url):
             parsed_url = urlparse.urlparse(value)
-            parse_qs = urlparse.parse_qs(parsed_url.query)
-            youtube_id = parse_qs['v'][0]
+            if parsed_url.netloc == 'youtu.be':
+                match = re.search("/([^/?#\s]+)", parsed_url.path)
+                if not match:
+                    return
+                youtube_id = match.group(1)
+            else:
+                parse_qs = urlparse.parse_qs(parsed_url.query)
+                youtube_id = parse_qs['v'][0]
             return '%s%s' % (youtube_embed_url, youtube_id)
 
         return value
